@@ -14,8 +14,10 @@
 
 #include <wchar.h>
 #include <wctype.h>
-#include <link-grammar/api.h>
-#include "utilities.h"  // For MSWindows portability
+#include <link-grammar/link-includes.h>
+
+#include "read-dict.h"  /* For non-public dict_display_word_info */
+#include "utilities.h"  /* For MSWindows portability */
 
 static struct
 {
