@@ -99,15 +99,16 @@ static void throwException(JNIEnv *env, const char* message)
 	if ((*env)->ExceptionOccurred(env) != NULL) return;
 
 	msg = (char *) malloc(50+strlen(message));
-	strcpy(msg, "link-parser:\n");
+	strcpy(msg, "link-grammar JNI:\n");
 	strcat(msg, message);
 	exceptionClazz = (*env)->FindClass(env, "java/lang/RuntimeException");
 	if ((*env)->ThrowNew(env, exceptionClazz, msg) != 0)
-		(*env)->FatalError(env, "Cannot throw");
+		(*env)->FatalError(env, "Fatal: link-grammar JNI: Cannot throw");
 }
 
 static per_thread_data * init(JNIEnv *env, jclass cls)
 {
+	const char *codeset, *dict_version;
 	per_thread_data *ptd;
 
 	/* Get the locale from the environment...
@@ -115,6 +116,17 @@ static per_thread_data * init(JNIEnv *env, jclass cls)
 	 */
 	setlocale(LC_ALL, "");
 
+	/* Everything breaks if the locale is not UTF-8; check for this,
+	 * and force  the issue !
+	 */
+	codeset = nl_langinfo(CODESET);
+	if (!strstr(codeset, "UTF") && !strstr(codeset, "utf"))
+	{
+		prt_error("Warning: JNI: locale %s was not UTF-8; force-setting to en_US.UTF-8\n",
+			codeset);
+		setlocale(LC_CTYPE, "en_US.UTF-8");
+	}
+
 	ptd = (per_thread_data *) malloc(sizeof(per_thread_data));
 	memset(ptd, 0, sizeof(per_thread_data));
 
@@ -137,6 +149,9 @@ static per_thread_data * init(JNIEnv *env, jclass cls)
 	if (!ptd->dict) throwException(env, "Error: unable to open dictionary");
 	else test();
 
+	dict_version = linkgrammar_get_dict_version(ptd->dict);
+	prt_error("Info: JNI: dictionary version %s\n", dict_version);
+
 	return ptd;
 }
 
@@ -231,7 +246,7 @@ static void jParse(JNIEnv *env, per_thread_data *ptd, char* inputString)
 	if (maxlen < sentence_length(ptd->sent))
 	{
 		if (jverbosity > 0) {
-			prt_error("Error: Sentence length (%d words) exceeds maximum allowable (%d words)\n",
+			prt_error("Error: JNI: Sentence length (%d words) exceeds maximum allowable (%d words)\n",
 				sentence_length(ptd->sent), maxlen);
 		}
 		sentence_delete(ptd->sent);
@@ -248,17 +263,10 @@ static void jParse(JNIEnv *env, per_thread_data *ptd, char* inputString)
 
 	ptd->num_linkages = sentence_parse(ptd->sent, ptd->opts);
 
-	/* If failed, try with fat links ... */
-	if ((0 == ptd->num_linkages) && sentence_contains_conjunction(ptd->sent))
-	{
-		parse_options_set_use_fat_links(opts, TRUE);
-		ptd->num_linkages = sentence_parse(ptd->sent, ptd->opts);
-	}
-
-	/* If still failed, try again with null links */
+	/* If failed, try again with null links */
 	if (0 == ptd->num_linkages)
 	{
-		if (jverbosity > 0) prt_error("Warning: No complete linkages found.\n");
+		if (jverbosity > 0) prt_error("Warning: JNI: No complete linkages found.\n");
 		if (parse_options_get_allow_null(opts))
 		{
 			parse_options_set_min_null_count(opts, 1);
@@ -269,23 +277,23 @@ static void jParse(JNIEnv *env, per_thread_data *ptd, char* inputString)
 
 	if (parse_options_timer_expired(opts))
 	{
-		if (jverbosity > 0) prt_error("Warning: Timer is expired!\n");
+		if (jverbosity > 0) prt_error("Warning: JNI: Timer is expired!\n");
 	}
 	if (parse_options_memory_exhausted(opts))
 	{
-		if (jverbosity > 0) prt_error("Warning: Memory is exhausted!\n");
+		if (jverbosity > 0) prt_error("Warning: JNI: Memory is exhausted!\n");
 	}
 
 	if ((ptd->num_linkages == 0) &&
 	    parse_options_resources_exhausted(opts))
 	{
 		parse_options_print_total_time(opts);
-		if (jverbosity > 0) prt_error("Warning: Entering \"panic\" mode...\n");
+		if (jverbosity > 0) prt_error("Warning: JNI: Entering \"panic\" mode...\n");
 		parse_options_reset_resources(ptd->panic_parse_opts);
 		parse_options_set_verbosity(ptd->panic_parse_opts, jverbosity);
 		ptd->num_linkages = sentence_parse(ptd->sent, ptd->panic_parse_opts);
 		if (parse_options_timer_expired(ptd->panic_parse_opts)) {
-			if (jverbosity > 0) prt_error("Error: Timer is expired!\n");
+			if (jverbosity > 0) prt_error("Error: JNI: Timer is expired!\n");
 		}
 	}
 }
