@@ -13,7 +13,7 @@
 
 #include <wchar.h>
 #include <wctype.h>
-#include <link-grammar/api.h>
+#include "api.h"
 #include "error.h"
 
 /**
